@@ -6,7 +6,7 @@ from inspect import signature
 from typing import Any
 
 from awslambdaric.lambda_context import LambdaContext
-from openapi_schema_pydantic.v3.v3_0_3 import (
+from openapi_pydantic import (
     Components,
     Info,
     OpenAPI,
@@ -15,10 +15,7 @@ from openapi_schema_pydantic.v3.v3_0_3 import (
     Response,
     Schema,
 )
-from openapi_schema_pydantic.v3.v3_0_3.util import (
-    PydanticSchema,
-    construct_open_api_with_schema_class,
-)
+from openapi_pydantic.util import PydanticSchema, construct_open_api_with_schema_class
 from pydantic import BaseModel, create_model
 
 from pydantic_lambda_handler.main import PydanticLambdaHandler
@@ -61,12 +58,12 @@ class APIGenerationHook(BaseHook):
         if kwargs.get("errors"):
             for e_status_code, errors in kwargs["errors"]:
                 if inspect.isclass(errors) and issubclass(errors, Exception):
-                    responses[int(e_status_code)] = Response(
+                    responses[str(int(e_status_code))] = Response(
                         description=getattr(errors, "description", None) or inspect.getdoc(errors),
                         content={"application/json": {}},
                     )
                 else:
-                    responses[int(e_status_code)] = Response(
+                    responses[str(int(e_status_code))] = Response(
                         description=client.responses[int(e_status_code)],
                         content={"application/json": {}},
                     )
@@ -78,7 +75,6 @@ class APIGenerationHook(BaseHook):
             )
 
         else:
-
             cls.paths[url] = PathItem(
                 **{cls.method: Operation(responses=responses)},
             )
@@ -91,7 +87,6 @@ class APIGenerationHook(BaseHook):
         sig = signature(kwargs["func"])
 
         if sig.parameters:
-
             url = kwargs["url"]
 
             path_model_dict = {}
@@ -149,19 +144,22 @@ class APIGenerationHook(BaseHook):
 
             APIPathModel = create_model("APIPathModel", **path_model_dict, **query_model_dict, **headers)  # type: ignore
 
-            path_schema_initial = APIPathModel.schema()
+            path_schema_initial = APIPathModel.schema(ref_template="#/components/schemas/{model}")
             properties = []
             for name, property_info in path_schema_initial.get("properties", {}).items():
                 if "$ref" in property_info:
-                    property_info["$ref"] = property_info["$ref"].replace("#/definitions/", "#/components/schemas/")
                     for key, value in path_schema_initial.get("definitions", {}).items():
                         cls.schemas[key] = Schema.parse_obj(value)
 
-                if isinstance(param_info.default, Header):
-                    if param_info.default.include_in_schema is False:
+                # FIXME: This is ugly, please refactor
+                alias_header = next((h for _, h in headers.values() if h.alias == name), None)
+                if name in headers or alias_header:
+                    if (name in headers and headers[name][1].include_in_schema is False) or (
+                        alias_header and alias_header.include_in_schema is False
+                    ):
                         continue
 
-                    p = {"name": name, "in": "headers", "schema": property_info}
+                    p = {"name": name, "in": "header", "schema": property_info}
                     if name in path_schema_initial.get("required", ()):
                         p["required"] = True
                     properties.append(p)
