@@ -1,6 +1,7 @@
 """
 The main class which you import and use as a decorator.
 """
+
 import datetime
 import functools
 import json
@@ -15,7 +16,7 @@ from inspect import isclass, signature
 from typing import Any, Optional, Union
 
 from awslambdaric.lambda_context import LambdaContext
-from orjson import loads
+from orjson import JSONDecodeError, loads
 from pydantic import BaseModel, ValidationError, create_model
 
 from pydantic_lambda_handler.middleware import BaseHook
@@ -150,8 +151,16 @@ class PydanticLambdaHandler:
                             response = BaseOutput(
                                 body=json.dumps({"detail": json.loads(e.json())}),
                                 status_code=HTTPStatus.UNPROCESSABLE_ENTITY,
+                                is_base_64_encoded=False,
                             )
-                            return loads(response.json())
+                            return response.model_dump(mode="json")
+                        except JSONDecodeError:
+                            response = BaseOutput(
+                                body=json.dumps({"detail": "JSONDecodeError"}),
+                                status_code=HTTPStatus.BAD_REQUEST,
+                                is_base_64_encoded=False,
+                            )
+                            return response.model_dump(mode="json")
 
                         # Do something before
                         func_kwargs = {
@@ -195,27 +204,28 @@ class PydanticLambdaHandler:
                                             }
                                         )
                                     response = BaseOutput(
-                                        body=body,
-                                        status_code=e_status_code,
+                                        body=body, status_code=e_status_code, is_base_64_encoded=False
                                     )
-                                    return loads(response.json())
+                                    return response.model_dump(mode="json")
                         raise
 
                     for hook in reversed(self._hooks):
                         body = hook.post_func(body)
 
-                    if response_model:
-                        body = response_model.parse_obj(body)
+                    if response_model and not isinstance(body, response_model):
+                        body = response_model.model_validate(body, from_attributes=True)
 
                     if hasattr(body, "json"):
-                        base_output = BaseOutput(body=body.json(), status_code=status_code)
+                        base_output = BaseOutput(body=body.json(), status_code=status_code, is_base_64_encoded=False)
                     else:
-                        base_output = BaseOutput(body=json.dumps(body), status_code=status_code)
+                        base_output = BaseOutput(
+                            body=json.dumps(body), status_code=status_code, is_base_64_encoded=False
+                        )
 
                     for hook in self._hooks:
-                        body = hook.pre_return(base_output)
+                        hook.pre_return(base_output)
 
-                    response = loads(base_output.json())
+                    response = base_output.model_dump(mode="json")  # type: ignore
                 except Exception as error:
                     traceback.print_exc(file=sys.stdout)
                     self.logger.error(f"{type(error).__name__}: {error}")
@@ -312,8 +322,7 @@ class PydanticLambdaHandler:
         query_parameters = event.get("queryStringParameters", {}) or {}
         multiquery_parameters = event.get("multiValueQueryStringParameters", {}) or {}
         headers = event.get("headers", {}) or {}
-        body = loads(event["body"]) if event.get("body") is not None else None
-
+        body = loads(event["body"]) if event.get("body") else None
         return EventModel(
             path=path_parameters, query=query_parameters, multiquery=multiquery_parameters, body=body, headers=headers
         )
